@@ -2,7 +2,7 @@
  * Copyright (C) 2008 Canonical Ltd
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 3 as 
+ * it under the terms of the GNU General Public License version 3 as
  * published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -40,14 +40,16 @@
 
 #define APPLET_SCHEMA "org.mate.panel.applet.mate-window-picker-applet"
 #define SHOW_WIN_KEY "show-all-windows"
+#define SHOW_HOME_TITLE_KEY "show-home-title"
+#define BOLD_WINDOW_TITLE_KEY "bold-window-title"
 
-typedef struct 
+typedef struct
 {
   GtkWidget    *tasks;
   GtkWidget    *applet;
   GtkWidget    *title;
   GSettings    *settings;
-  
+
 } WinPickerApp;
 
 static WinPickerApp *mainapp;
@@ -89,6 +91,34 @@ on_show_all_windows_changed (GSettings   *settings,
   g_object_set (app->tasks, "show_all_windows", show_windows, NULL);
 }
 
+static void
+on_show_home_title_changed (GSettings   *settings,
+                            gchar       *key,
+                            gpointer     data)
+{
+  WinPickerApp *app;
+  gboolean show_home = FALSE;
+
+  app = (WinPickerApp*)data;
+
+  show_home = g_settings_get_boolean (settings, SHOW_HOME_TITLE_KEY);
+  g_object_set (app->title, "show_home_title", show_home, NULL);
+}
+
+static void
+on_bold_window_title_changed (GSettings   *settings,
+                              gchar       *key,
+                              gpointer     data)
+{
+  WinPickerApp *app;
+  gboolean bold_win = TRUE;
+
+  app = (WinPickerApp*)data;
+
+  bold_win = g_settings_get_boolean (settings, BOLD_WINDOW_TITLE_KEY);
+  g_object_set (app->title, "bold_window_title", bold_win, NULL);
+}
+
 static inline void
 force_no_focus_padding (GtkWidget *widget)
 {
@@ -119,20 +149,19 @@ cw_applet_finalize (GObject *object)
 }
 
 static gboolean
-cw_applet_fill (MatePanelApplet *applet, 
-                const gchar *iid, 
+cw_applet_fill (MatePanelApplet *applet,
+                const gchar *iid,
                 gpointer     data)
 {
-  WnckScreen *screen;
   WinPickerApp *app;
   GtkWidget *eb, *tasks, *title;
   gchar *ui_path;
   GtkActionGroup *action_group;
   GObjectClass *object_class;
-  
+
   if (strcmp (iid, "MateWindowPicker") != 0)
     return FALSE;
-  	
+
   bindtextdomain (GETTEXT_PACKAGE, MATELOCALEDIR);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
@@ -141,10 +170,9 @@ cw_applet_fill (MatePanelApplet *applet,
   mate_panel_applet_set_background_widget (MATE_PANEL_APPLET (applet), GTK_WIDGET (applet));
 
   wnck_set_client_type (WNCK_CLIENT_TYPE_PAGER);
-  
+
   app = g_slice_new0 (WinPickerApp);
   mainapp = app;
-  screen = wnck_screen_get_default ();
 
   object_class = G_OBJECT_GET_CLASS (G_OBJECT(applet));
   object_class->finalize = cw_applet_finalize;
@@ -154,6 +182,10 @@ cw_applet_fill (MatePanelApplet *applet,
   app->settings = mate_panel_applet_settings_new (applet, APPLET_SCHEMA);
   g_signal_connect (app->settings, "changed::" SHOW_WIN_KEY,
                     G_CALLBACK (on_show_all_windows_changed), app);
+  g_signal_connect (app->settings, "changed::" SHOW_HOME_TITLE_KEY,
+                    G_CALLBACK (on_show_home_title_changed), app);
+  g_signal_connect (app->settings, "changed::" BOLD_WINDOW_TITLE_KEY,
+                    G_CALLBACK (on_bold_window_title_changed), app);
 
   app->applet = GTK_WIDGET (applet);
   force_no_focus_padding (GTK_WIDGET (applet));
@@ -170,9 +202,11 @@ cw_applet_fill (MatePanelApplet *applet,
   gtk_box_pack_start (GTK_BOX (eb), title, TRUE, TRUE, 0);
 
   gtk_widget_show_all (GTK_WIDGET (applet));
-	
+
   on_show_all_windows_changed (app->settings, SHOW_WIN_KEY, app);
-		
+  on_show_home_title_changed (app->settings, SHOW_HOME_TITLE_KEY, app);
+  on_bold_window_title_changed (app->settings, BOLD_WINDOW_TITLE_KEY, app);
+
   action_group = gtk_action_group_new ("MateWindowPicker Applet Actions");
   gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
   gtk_action_group_add_actions (action_group,
@@ -185,11 +219,11 @@ cw_applet_fill (MatePanelApplet *applet,
   g_free (ui_path);
   g_object_unref (action_group);
 
-  mate_panel_applet_set_flags (MATE_PANEL_APPLET (applet), 
+  mate_panel_applet_set_flags (MATE_PANEL_APPLET (applet),
                                MATE_PANEL_APPLET_EXPAND_MAJOR
                                | MATE_PANEL_APPLET_EXPAND_MINOR
                                | MATE_PANEL_APPLET_HAS_HANDLE);
-	
+
   return TRUE;
 }
 
@@ -204,7 +238,7 @@ display_about_dialog (GtkAction       *action,
                       WinPickerApp *applet)
 {
   GtkWidget *panel_about_dialog;
-	
+
   panel_about_dialog = gtk_about_dialog_new ();
 
   g_object_set (panel_about_dialog,
@@ -228,15 +262,35 @@ display_about_dialog (GtkAction       *action,
 }
 
 static void
-on_checkbox_toggled (GtkToggleButton *check, gpointer null)
+on_show_win_key_checkbox_toggled (GtkToggleButton *check, gpointer null)
 {
   gboolean is_active;
-    
+
   is_active = gtk_toggle_button_get_active (check);
 
   g_settings_set_boolean (mainapp->settings, SHOW_WIN_KEY, is_active);
 }
 
+static void
+on_show_home_title_checkbox_toggled (GtkToggleButton *check, gpointer null)
+{
+  gboolean is_active;
+
+  is_active = gtk_toggle_button_get_active (check);
+
+  g_settings_set_boolean (mainapp->settings, SHOW_HOME_TITLE_KEY, is_active);
+}
+
+static void
+on_bold_window_title_checkbox_toggled (GtkToggleButton *check, gpointer null)
+{
+  gboolean is_active;
+
+  is_active = gtk_toggle_button_get_active (check);
+
+  g_settings_set_boolean (mainapp->settings, BOLD_WINDOW_TITLE_KEY, is_active);
+}
+
 static void
 display_prefs_dialog (GtkAction       *action,
                       WinPickerApp *applet)
@@ -261,27 +315,47 @@ display_prefs_dialog (GtkAction       *action,
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 8);
   gtk_notebook_append_page (GTK_NOTEBOOK (nb), vbox, NULL);
 
-  check = gtk_check_button_new_with_label (_("Show windows from all workspaces"));
+  check = gtk_check_button_new_with_label (_("Show all windows"));
+  gtk_widget_set_tooltip_text (GTK_WIDGET (check),
+                               _("Show windows from all workspaces."));
   gtk_box_pack_start (GTK_BOX (vbox), check, FALSE, TRUE, 0);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check),
                                 g_settings_get_boolean (mainapp->settings, SHOW_WIN_KEY));
   g_signal_connect (check, "toggled",
-                    G_CALLBACK (on_checkbox_toggled), NULL);
+                    G_CALLBACK (on_show_win_key_checkbox_toggled), NULL);
+
+  check = gtk_check_button_new_with_label (_("Show desktop title and logout button"));
+  gtk_widget_set_tooltip_text (GTK_WIDGET (check),
+                               _("Show a title for the desktop when no window is selected, and append a logout button."));
+  gtk_box_pack_start (GTK_BOX (vbox), check, FALSE, TRUE, 0);
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check),
+                                g_settings_get_boolean (mainapp->settings, SHOW_HOME_TITLE_KEY));
+  g_signal_connect (check, "toggled",
+                    G_CALLBACK (on_show_home_title_checkbox_toggled), NULL);
+
+  check = gtk_check_button_new_with_label (_("Bold windows title"));
+  gtk_widget_set_tooltip_text (GTK_WIDGET (check),
+                               _("Show windows title with a bold face."));
+  gtk_box_pack_start (GTK_BOX (vbox), check, FALSE, TRUE, 0);
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check),
+                                g_settings_get_boolean (mainapp->settings, BOLD_WINDOW_TITLE_KEY));
+  g_signal_connect (check, "toggled",
+                    G_CALLBACK (on_bold_window_title_checkbox_toggled), NULL);
 
   check = gtk_label_new (" ");
   gtk_box_pack_start (GTK_BOX (vbox), check, TRUE, TRUE, 0);
 
   gtk_widget_set_size_request (nb, -1, 100);
-  
+
   hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   gtk_box_pack_start (GTK_BOX (box), hbox, FALSE, FALSE, 0);
-  
+
   label = gtk_label_new (" ");
   gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
 
   button = gtk_button_new_from_stock (GTK_STOCK_CLOSE);
   gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
-	
+
   gtk_widget_show_all (window);
 
   g_signal_connect (window, "delete-event",
@@ -291,6 +365,6 @@ display_prefs_dialog (GtkAction       *action,
                     G_CALLBACK (gtk_widget_destroy), window);
   g_signal_connect_swapped (button, "clicked",
                             G_CALLBACK (gtk_widget_destroy), window);
-	
+
   gtk_window_present (GTK_WINDOW (window));
 }
